# Contributing to _Conversations_

Contributions are immensely appreciated and welcomed.


## Development Process

### Standards

To ensure effecient collaborative development, a variety of standards are utilised in this project.

- [Semantic Versioning](https://semver.org) is used.
  - [Python Semantic Releases](https://github.com/python-semantic-release/python-semantic-release) is used to automate change log generation and releases.
- [Conventional Commits](https://www.conventionalcommits.org/) are utilised and validated using the [wagoid/commitlint-github-action](https://github.com/wagoid/commitlint-github-action) github action, which itself uses [commitlint](https://github.com/conventional-changelog/commitlint)
  - Conventional Commmits are also utilised for pull request titles and enforced using [amannn/action-semantic-pull-request](https://github.com/amannn/action-semantic-pull-request).
